@@ -31,8 +31,6 @@ BEGIN{
 	}
 }
 
-print "Perl $] on $^O\n";
-
 foreach my $x (Foo->new, Foo::X::X::X->new, Unrelated->new, undef, {}){
 	print 'For ', neat($x), "\n";
 
@@ -49,7 +47,7 @@ foreach my $x (Foo->new, Foo::X::X::X->new, Unrelated->new, undef, {}){
 				$i++ if blessed($x) && $x->isa('Foo');
 			}
 		},
-		'is_instance()' => sub{
+		'instance()' => sub{
 			for(1 .. 10){
 				$i++ if is_instance($x, 'Foo');
 			}
